@@ -181,6 +181,14 @@ you might want to use a L<IO::Handle> type of object (Something that implements
 in the same fashion), or a filehandle GLOB. Catalyst
 will write it piece by piece into the response.
 
+When using a L<IO::Handle> type of object and no content length has been
+already set in the response headers Catalyst will make a reasonable attempt
+to determine the size of the Handle. Depending on the implementation of your
+handle object, setting the content length may fail. If it is at all possible
+for you to determine the content length of your handle object, 
+it is recommended that you set the content length in the response headers
+yourself, which will be respected and sent by Catalyst in the response.
+
 =head2 $res->has_body
 
 Predicate which returns true when a body has been set.
@@ -362,7 +370,7 @@ Example:
 
     sub myaction :Local Args {
       my ($self, $c) = @_;
-      $c->res->from_psgi_response($app->($self->env));
+      $c->res->from_psgi_response($app->($c->req->env));
     }
 
 Please note this does not attempt to map or nest your PSGI application under
